@@ -10,8 +10,8 @@ from itertools import chain
 import logging
 import operator
 import re
+import traceback
 
-from collections import OrderedDict
 from functools import wraps, partial, lru_cache, update_wrapper
 from types import MethodType
 
@@ -22,7 +22,6 @@ from sanic.views import HTTPMethodView
 from sanic_jinja2 import SanicJinja2
 from spf.plugin import FutureRoute, FutureStatic
 
-
 try:
     from sanic.response import ALL_STATUS_CODES
 except ImportError:
@@ -46,12 +45,13 @@ from .namespace import Namespace
 from .postman import PostmanCollectionV1
 from .resource import Resource
 from .swagger import Swagger
-from .utils import default_id, camel_to_dash, unpack, best_match_accept_mimetype, get_accept_mimetypes
+from .utils import OrderedDict, cur_py_version, default_id, camel_to_dash, unpack, best_match_accept_mimetype, get_accept_mimetypes
 from .representations import output_json_fast
 from ._http import HTTPStatus
 
-async_req_version = (3, 6)
-cur_py_version = sys.version_info
+
+py_36 = (3, 6)
+async_req_version = py_36
 
 RE_RULES = re.compile('(<.*>)')
 
@@ -142,8 +142,10 @@ class Api(object):
             path='/',
         )
         self.ns_paths = dict()
-
-        self.representations = OrderedDict(DEFAULT_REPRESENTATIONS)
+        if py_36 > cur_py_version: #py3.5 or below
+            self.representations = OrderedDict(DEFAULT_REPRESENTATIONS)
+        else:
+            self.representations = dict(DEFAULT_REPRESENTATIONS)
         self.urls = {}
         self.prefix = prefix
         self.default_mediatype = default_mediatype
@@ -849,9 +851,18 @@ class Api(object):
 
         if code >= HTTPStatus.INTERNAL_SERVER_ERROR:
             exc_info = sys.exc_info()
-            if exc_info[1] is None:
-                exc_info = None
-            context.log(logging.ERROR, exc_info)
+            if exc_info[1] is None or exc_info[0] is None:
+                e_type = e.__class__
+                e_value = e
+                e_traceback = e.__traceback__
+            else:
+                e_type, e_value, e_traceback = exc_info
+
+            context.log(logging.ERROR, "Caught Exception: {}".format(str(e_type)))
+            context.log(logging.ERROR, "Detail: {}".format(str(e_value)))
+            tb = traceback.format_tb(e_traceback)
+            tb = "".join(tb)
+            context.log(logging.ERROR, "Traceback:\n{}".format(tb))
 
         elif code == HTTPStatus.NOT_FOUND and app.config.get("ERROR_404_HELP", False) \
                 and include_message_in_response:
@@ -1059,7 +1070,7 @@ class SwaggerView(Resource):
     '''Render the Swagger specifications as JSON'''
     def get(self, request):
         schema = self.api.__schema__
-        return schema, HTTPStatus.INTERNAL_SERVER_ERROR if 'error' in schema else HTTPStatus.OK
+        return schema, HTTPStatus.INTERNAL_SERVER_ERROR.value if 'error' in schema else HTTPStatus.OK.value
 
     def mediatypes(self):
         return ['application/json']
@@ -1067,9 +1078,9 @@ class SwaggerView(Resource):
 
 def mask_parse_error_handler(error):
     '''When a mask can't be parsed'''
-    return {'message': 'Mask parse error: {0}'.format(error)}, HTTPStatus.BAD_REQUEST
+    return {'message': 'Mask parse error: {0}'.format(error)}, HTTPStatus.BAD_REQUEST.value
 
 
 def mask_error_handler(error):
     '''When any error occurs on mask'''
-    return {'message': 'Mask error: {0}'.format(error)}, HTTPStatus.BAD_REQUEST
+    return {'message': 'Mask error: {0}'.format(error)}, HTTPStatus.BAD_REQUEST.value
